@@ -93,6 +93,11 @@ ResultParser <- R6::R6Class(classname = "ResultParser",
                                   abnormalReturns <- data.table::copy(self[["arResults"]])
                                 }
                                 
+                                if (nrow(abnormalReturns) == 0) {
+                                  message("Analysis performed, but no AR Results. Please look at comments in Analysis report.")
+                                  return(NULL)
+                                }
+                                
                                 # parse Abnormal Returns
                                 stringr::str_detect(names(abnormalReturns), analysisType) %>%
                                   which() -> id
@@ -150,7 +155,7 @@ ResultParser <- R6::R6Class(classname = "ResultParser",
                                 # parse CAR values & check file
                                 carResults <- data.table::fread(path)
                                 if (nrow(carResults) == 0) {
-                                  message("No CAR Results")
+                                  message("Analysis performed, but no CAR Results. Please look at comments in Analysis report.")
                                   return(NULL)
                                 }
                                 
@@ -170,7 +175,7 @@ ResultParser <- R6::R6Class(classname = "ResultParser",
                                 # parse AAR values & check file
                                 aarResults <- data.table::fread(path)
                                 if (nrow(aarResults) < 2) {
-                                  message("No AAR Results")
+                                  message("Analysis performed, but no AAR Results. Please look at comments in Analysis report.")
                                   return(NULL)
                                 }
                                 
@@ -360,10 +365,11 @@ ResultParser <- R6::R6Class(classname = "ResultParser",
                             ),
                             private = list(
                               setCenterStyle = function(wb, sheet, rows, cols) {
+                                centreStyle <- openxlsx::createStyle(halign = "center", valign = "center")
                                 openxlsx::addStyle(wb,  sheet, 
                                                    style = centreStyle, 
-                                                   rows = 1:(nrow(dtData) + 1), 
-                                                   cols = 3:ncol(dtData), 
+                                                   rows = rows, 
+                                                   cols = cols, 
                                                    stack = T, 
                                                    gridExpand = TRUE)
                                 wb
